Package 'ggsegBrainnetome'

Title: Brainnetome Atlas for the 'ggsegverse' Ecosystem
Description: Brainnetome atlas for the 'ggseg' ecosystem. Provides cortical and subcortical 'ggseg_atlas' objects with 2D polygon geometry and 3D vertex indices for use with 'ggseg' and 'ggseg3d'.
Authors: Athanasia Mo Mowinckel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5756-0223>, github: drmowinckels)
Maintainer: Athanasia Mo Mowinckel <[email protected]>
License: MIT + file LICENSE
Version: 2.0.3
Built: 2026-05-24 07:09:02 UTC
Source: https://github.com/ggsegverse/ggsegBrainnetome

Help Index


Brainnetome Atlas

Description

Brain atlas for the Brainnetome cortical parcellation with 105 regions per hemisphere. Contains 2D polygon geometry for ggseg::geom_brain().

Usage

brainnetome()

Value

A ggseg.formats::ggseg_atlas object (cortical).

References

Fan L, Li H, Zhuo J, Zhang Y, Wang J, Chen L, Yang Z, Chu C, Xie S, Laird AR, Fox PT, Eickhoff SB, Yu C, Jiang T (2016). The Human Brainnetome Atlas: A New Brain Atlas Based on Connectional Architecture. Cerebral Cortex, 26(8):3508-3526. doi:10.1093/cercor/bhw157

See Also

Other ggseg_atlases: brainnetome_sub()

Examples

brainnetome()
## Not run: plot(brainnetome())

Brainnetome Subcortical Atlas

Description

Brain atlas for the Brainnetome subcortical parcellation with 36 subregions covering amygdala, hippocampus, thalamus, caudate, putamen, pallidum, and nucleus accumbens.

Usage

brainnetome_sub()

Value

A ggseg.formats::ggseg_atlas object (subcortical).

References

Fan L, Li H, Zhuo J, Zhang Y, Wang J, Chen L, Yang Z, Chu C, Xie S, Laird AR, Fox PT, Eickhoff SB, Yu C, Jiang T (2016). The Human Brainnetome Atlas: A New Brain Atlas Based on Connectional Architecture. Cerebral Cortex, 26(8):3508-3526. doi:10.1093/cercor/bhw157

See Also

Other ggseg_atlases: brainnetome()

Examples

brainnetome_sub()
## Not run: plot(brainnetome_sub())